View source: R/calculate_covariates_auxiliary.R
| calc_prepare_locs | R Documentation |
Prepare the point locations for extracting data by transforming locs to
a SpatVector, projecting to the coordinate reference system of from,
and creating a data.frame containing locs_id for retaining extracted
values.
calc_prepare_locs(from, locs, locs_id, radius, geom = FALSE)
from |
SpatRaster(1) or SpatVector(1). Output from
|
locs |
data.frame. character to file path, SpatVector, or sf object.
Passed from |
locs_id |
character(1). Column within |
radius |
integer(1). Circular buffer distance around site locations.
(Default = 0). Passed from |
geom |
logical(1). Should the geometry of |
A list containing SpatVector and data.frame objects
process_locs_vector(), check_for_null_parameters()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.