View source: R/process_auxiliary.R
| process_locs_vector | R Documentation |
SpatVectorDetect SpatVector object, or convert locations from class sf,
data.frame or data.table to
SpatVector object, project to coordinate reference system, and apply
circular buffer.
process_locs_vector(locs, crs, radius)
locs |
data.frame(1). Data frame containing columns for unique identifier, latitude, and longitude. Latitude and longitude columns must be named "lat" and "lon", respectively. |
crs |
Coordinate reference system (CRS) description utilizing
|
radius |
integer(1). Circular buffer size (meters). |
a SpatVector object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.