View source: R/manipulate_spacetime_data.R
| sftime_as_spatraster | R Documentation |
sftime to a SpatRasterConvert an sftime object to a SpatRaster object. Returns a
SpatRatser with one layer for each time step in x.
sftime_as_spatraster(x, varname)
x |
an |
varname |
variable to rasterize |
a SpatRaster object
Running sftime_as_spatraster can take a long time if x is not
spatially structured.
Eva Marques
terra::rast
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.