View source: R/manipulate_spacetime_data.R
| spatraster_as_sftime | R Documentation |
SpatRaster to an sftimeConvert a SpatRaster object to an sftime object. x must
contain a time-defining column, identified in timename.
spatraster_as_sftime(x, varname, timename = "time")
x |
a |
varname |
character for variable column name in the sftime |
timename |
character for time column name in the sftime (default: "time") |
a sftime object
Eva Marques
terra::rast
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.