test: Run all tests within a single file from tests/testthat/...

View source: R/helpers.R

testR Documentation

Run all tests within a single file from ⁠tests/testthat/⁠ directory with the container.sif container.

Description

Run all tests within a single file from ⁠tests/testthat/⁠ directory with the container.sif container.

Usage

test(pattern = NULL)

Arguments

pattern

A regular expression to match the test file name.

Value

NULL; Prints the output of the testthat tests.

See Also

testthat::test_file()


amadeus documentation built on Jan. 27, 2026, 1:07 a.m.