| download_data | R Documentation |
The download_data() function accesses and downloads atmospheric, meteorological, and environmental data from various open-access data sources.
download_data(
dataset_name = c("aqs", "ecoregion", "ecoregions", "geos", "gmted", "koppen",
"koppengeiger", "merra2", "merra", "modis", "narr", "nlcd", "noaa", "sedac_groads",
"sedac_population", "groads", "population", "hms", "smoke", "tri", "nei", "gridmet",
"terraclimate", "huc", "cropscape", "cdl", "prism"),
directory_to_save = NULL,
acknowledgement = FALSE,
hash = FALSE,
...
)
dataset_name |
character(1). Dataset to download. |
directory_to_save |
character(1). Directory to save / unzip (if zip files are downloaded) data. |
acknowledgement |
logical(1). By setting |
hash |
logical(1). By setting |
... |
Arguments passed to each download function. |
For hash = FALSE, NULL
For hash = TRUE, an rlang::hash_file character.
Data files will be downloaded and stored in respective
sub-directories within directory_to_save. File format and
sub-directory names depend on data source and dataset of interest.
All download function names are in download_* formats
Insang Song
For details of each download function per dataset, Please refer to:
download_aqs: "aqs", "AQS"
download_ecoregion: "ecoregions", "ecoregion"
download_geos: "geos"
download_gmted: "gmted", "GMTED"
download_koppen_geiger: "koppen", "koppengeiger"
download_merra2: "merra2", "merra", "MERRA", "MERRA2"
download_narr: "narr"
download_nlcd: "nlcd", "NLCD"
download_hms: "noaa", "smoke", "hms"
download_groads: "sedac_groads", "groads"
download_population: "sedac_population",
"population"
download_modis: "modis", "MODIS"
download_tri: "tri", "TRI"
download_nei: "nei", "NEI"
download_gridmet: "gridMET", "gridmet"
download_terraclimate: "TerraClimate", "terraclimate"
download_huc: "huc"
download_cropscape: "cropscape", "cdl"
download_prism: "prism"
download_edgar: "edgar", "EDGAR"
## Not run:
download_data(
dataset_name = "narr",
variables = "weasd",
year = 2023,
directory_to_save = tempdir(),
acknowledgement = TRUE,
download = FALSE, # NOTE: download skipped for examples,
remove_command = TRUE
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.