The download_narr function accesses and downloads daily meteorological
data from NOAA's North American Regional Reanalysis (NARR) model via the
NOAA Physical Sciences Laboratory (PSL) NARR Dailies server
(https://downloads.psl.noaa.gov/Datasets/NARR/Dailies/).
Usage
download_narr(
variables = NULL,
year = c(2018, 2022),
directory_to_save = NULL,
acknowledgement = FALSE,
download = TRUE,
remove_command = FALSE,
show_progress = TRUE,
hash = FALSE,
max_tries = 20,
rate_limit = 2
)Arguments
- variables
character. Variable(s) name acronym. See the Available NARR Variables section below for the complete list of supported abbreviations.
- year
integer(1 or 2). Year or start/end years for downloading data.
- directory_to_save
character(1). Directory to save downloaded data files.
- acknowledgement
logical(1). Must be TRUE to proceed with download.
- download
logical(1). DEPRECATED. Downloads happen automatically.
- remove_command
logical(1). DEPRECATED, ignored.
- show_progress
logical(1). Show download progress (default TRUE)
- hash
logical(1). Return hash of downloaded files (default FALSE)
- max_tries
integer(1). Maximum download retry attempts (default 20)
- rate_limit
numeric(1). Minimum seconds between requests (default 2)
Note
"Pressure levels" variables contain variable values at 29 atmospheric levels, ranging from 1000 hPa to 100 hPa. All pressure levels data will be downloaded for each variable.
The 88 variables supported by this function represent the complete set
of variables available as individual NetCDF files on the PSL NARR Dailies
server. The NARR archive also contains additional variables (e.g., cloud
water mixing ratio, ice mixing ratio, surface friction velocity, momentum
fluxes, and static land/soil properties) that are only present in the raw
merged GRIB files (merged_AWIP32.YYYYMMDDHH) available at
https://ftp.cpc.ncep.noaa.gov/NARR/. Those variables cannot be
downloaded with this function.
Available NARR Variables
The variables argument accepts one or more of the following
abbreviations. Variables are grouped into three categories that determine
the source URL path used for download.
Monolevel variables (single vertical level, surface / near-surface fields):
acpcpConvective precipitation
air.2mAir temperature at 2 m
air.sfcAir temperature at surface
albedoSurface albedo
apcpTotal accumulated precipitation
bgrunBaseflow-groundwater runoff
bmixl.hl1Blackadar mixing length scale at hybrid level 1
capeConvective available potential energy
ccondCanopy conductance
cdconConvective cloud cover
cdlyrNon-convective cloud cover
cfrzrCategorical freezing rain
cicepCategorical ice pellets
cinConvective inhibition
cnwatPlant canopy surface water
crainCategorical rain
csnowCategorical snow
dlwrfDownward longwave radiation flux
dpt.2mDew point temperature at 2 m
dswrfDownward shortwave radiation flux
evapEvaporation
gfluxGround heat flux
hcdcHigh cloud cover
hgt.tropoGeopotential height at tropopause
hlcyStorm relative helicity
hpblPlanetary boundary layer height
lcdcLow cloud cover
lftx4Best (4-layer) lifted index
lhtflLatent heat net flux
mcdcMid-cloud cover
mconv.hl1Horizontal moisture divergence at hybrid level 1
msletMean sea level pressure (ETA model reduction)
mstavMoisture availability
pevapPotential evaporation
pottmp.hl1Potential temperature at hybrid level 1
pottmp.sfcPotential temperature at surface
pratePrecipitation rate
pres.sfcSurface pressure
pres.tropoPressure at tropopause
prmslPressure reduced to mean sea level
pr_wtrPrecipitable water
rcqSpecific humidity tendency from all physics
rcsSnowfall water equivalent tendency
rcsolSolar radiative heating rates
rctTemperature tendency from all physics
rhum.2mRelative humidity at 2 m
shtflSensible heat net flux
shum.2mSpecific humidity at 2 m
snodSnow depth
snohfSnow phase-change heat flux
snomSnow melt
snowcSnow cover
soilmSoil moisture content (0–200 cm layer)
ssrunStorm surface runoff
tcdcTotal cloud cover
tke.hl1Turbulent kinetic energy at hybrid level 1
ulwrf.ntatUpward longwave radiation flux at nominal top of atmosphere
ulwrf.sfcUpward longwave radiation flux at surface
ustmU-component of storm motion
uswrf.ntatUpward shortwave radiation flux at nominal top of atmosphere
uswrf.sfcUpward shortwave radiation flux at surface
uwnd.10mU-component of wind at 10 m
vegVegetation fraction
visVisibility
vstmV-component of storm motion
vvel.hl1Vertical velocity at hybrid level 1
vwnd.10mV-component of wind at 10 m
vwsh.tropoVertical wind shear at tropopause
wcconvConvective wetting of vegetation canopy
wcincWetting of vegetation canopy
wcuflxU-component of convective canopy moisture flux
wcvflxV-component of convective canopy moisture flux
weasdWater-equivalent accumulated snow depth
wvconvConvective column moisture convergence
wvincColumn moisture increase
wvuflxU-component of vertically-integrated moisture flux
wvvflxV-component of vertically-integrated moisture flux
Pressure level variables (29 atmospheric pressure levels from 1000 to 100 hPa; all levels are downloaded together):
airAir temperature
hgtGeopotential height
omegaVertical velocity (pressure / omega)
shumSpecific humidity
tkeTurbulent kinetic energy
uwndU-component of wind
vwndV-component of wind
Subsurface (soil) variables (4 soil layers):
soillLiquid volumetric soil moisture (non-frozen fraction)
soilwVolumetric soil moisture content
tsoilSoil temperature
References
Mesinger F, DiMego G, Kalnay E, Mitchell K, Shafran PC, Ebisuzaki W, Jović D, Woollen J, Rogers E, Berbery EH, Ek MB, Fan Y, Grumbine R, Higgins W, Li H, Lin Y, Manikin G, Parrish D, Shi W (2006). “North American Regional Reanalysis.” Bulletin of the American Meteorological Society, 87(3), 343–360. ISSN 0003-0007, 1520-0477. doi:10.1175/BAMS-87-3-343 .