| test | R Documentation |
tests/testthat/ directory
with the container.sif container.Run all tests within a single file from tests/testthat/ directory
with the container.sif container.
test(pattern = NULL)
pattern |
A regular expression to match the test file name. |
NULL; Prints the output of the testthat tests.
testthat::test_file()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.